import click
import sys
import getpass
from .user import User


@click.group()
def main():
    pass


@click.command()
@click.option('-o', 'info', type=(int, int), default=(-1, -1), help='Show the gpa list, input the [year] you want to show firstly,'
                                                                    'and input [1] for the first, [2] for the second term.')
def gpa(info):
    """Show gpa list."""
    user = get_user_info()

    if info[0] == -1 and info[1] == -1:
        user.get.gpa()
    else:
        user.get.gpa_by(info[0], info[1])


@click.command()
def lecture():
    """Show lecture list."""
    user = get_user_info()
    user.get.lecture()


@click.command()
@click.option('-o', 'flag', type=int, default=0, help='Show the canceled lecture list, '
                                                      '[0] for the graduate, '
                                                      '[1] for the undergraduate student.')
def canceled(flag):
    """Show canceled lecture list."""
    User.get_canceled_lecture_list(flag)


# add command to group
main.add_command(gpa)
main.add_command(lecture)
main.add_command(canceled)


def get_user_info():
    # get user info
    if sys.stdin.isatty():
        print('Enter your uec username and password to login...')
        username = input('Username: ')
        password = getpass.getpass('Password: ')
    else:
        print('Username: ')
        username = sys.stdin.readline().rstrip()
        print('Password: ')
        password = sys.stdin.readline().rstrip()

    # return user
    user = User(username, password)
    return user

if __name__ == "__main__":
    main()



import requests
from bs4 import BeautifulSoup
from selenium import webdriver
from prettytable import PrettyTable
from progressbar import ProgressBar, Percentage, Bar
from selenium.webdriver.common.desired_capabilities import DesiredCapabilities

from .methods import Methods


class User(object):

    _login_url = 'https://campusweb.office.uec.ac.jp/campusweb/'

    def __init__(self, username, password):
        # login
        self.username = username
        self.password = password
        self._bar = ProgressBar(widgets=[Percentage(), Bar()], maxval=100).start()
        self._bar.update(10)

        self.get = Methods(self._login(), self._bar)

    def _login(self):
        self._bar.update(20)

        # desired capabilities
        desired_capabilities = DesiredCapabilities.CHROME

        # open url
        self._bar.update(30)
        driver = webdriver.PhantomJS(desired_capabilities=desired_capabilities)
        driver.get(self._login_url)

        # get username and password input box
        self._bar.update(40)
        username_box = driver.find_element_by_id('username')
        password_box = driver.find_element_by_id('password')

        # send username and password
        self._bar.update(50)
        username_box.send_keys(self.username)
        password_box.send_keys(self.password)

        # commit
        self._bar.update(60)
        driver.find_element_by_name('_eventId_proceed').click()

        return driver

    @staticmethod
    def get_canceled_lecture_list(flag):
        # no lecture urls
        url_0 = 'http://kyoumu.office.uec.ac.jp/kyuukou/kyuukou.html'
        url_1 = 'http://kyoumu.office.uec.ac.jp/kyuukou/kyuukou2.html'

        # get html
        response = None
        if flag == 0:
            response = requests.get(url_0)
        elif flag == 1:
            response = requests.get(url_1)
        response.encoding = response.apparent_encoding

        # get data
        soup = BeautifulSoup(response.text, 'lxml')
        tds = soup.find_all('td', {'align': 'CENTER'})

        # store data to array
        data = []
        for i in range(0, 5):
            data.append([])
            for j in range(i, len(tds), 5):
                data[i].append(tds[j].text)

        # create table and print
        table = PrettyTable()
        for i in range(1, 5):
            table.add_column(data[i][0], data[i][1:])
        print(table)



from selenium.webdriver.support.ui import Select
from bs4 import BeautifulSoup
from prettytable import PrettyTable


class Methods:

    _page_source = None

    def __init__(self, driver, bar):
        # web driver
        self._driver = driver
        self._bar = bar

    # get gpa
    def _prepare_driver_for_gpa(self):

        # switch to menu and enter gpa page
        self._bar.update(70)
        self._driver.switch_to.frame('menu')
        self._driver.find_element_by_xpath('/html/body/table/tbody/tr[8]/td/table/tbody/tr[2]/td/a').click()
        self._driver.switch_to.default_content()
        self._driver.switch_to.frame('body')

        # commit button
        self._commit_button = self._driver.find_element_by_xpath('//*[@id="taniReferListForm"]/table/tfoot/tr/td/input[1]')
        self._bar.update(80)

    def gpa(self):
        self._prepare_driver_for_gpa()

        # commit
        self._bar.update(90)
        self._commit_button.click()
        self._page_source = self._driver.page_source

        # get gpa data
        self._bar.update(100)
        self._bar.finish()
        self._get_data_for_gpa()

    def gpa_by(self, year, term):
        self._prepare_driver_for_gpa()

        # switch to year and term selection
        self._bar.update(90)
        self._driver.find_element_by_xpath('//*[@id="spanType2"]').click()

        # input year and select term
        self._driver.find_element_by_id('nendo').send_keys(str(year))
        Select(self._driver.find_element_by_name('gakkiKbnCd')).select_by_value(str(term))

        # commit
        self._bar.update(100)
        self._bar.finish()
        self._commit_button.click()
        self._page_source = self._driver.page_source
        self._get_data_for_gpa()

    def _get_data_for_gpa(self):
        count = 0
        soup = BeautifulSoup(self._page_source, 'lxml')

        # get user info table
        user_info = soup.find_all('tbody')[1]
        heads = user_info.find_all('th')
        values = user_info.find_all('td')

        # make table and print
        user_info_table = PrettyTable([heads[0].text.strip(), values[0].text.strip()])
        for index in range(1, len(heads)):
            user_info_table.add_row([heads[index].text.strip(), values[index].text.strip()])
        print(user_info_table)

        # get gpa details head
        heads = []
        for head in soup.find('thead').find('tr'):
            if head.string.strip() == '':
                continue
            heads.append(head.string.strip())

        # get gpa details value
        values = []
        for row in soup.find_all('tbody')[2].find_all('tr'):
            values.append([])
            for value in row.find_all('td'):
                values[count].append(value.string.strip())
            count += 1

        # make table and print
        count = 1
        gpa_details_table = PrettyTable([heads[0], heads[4], heads[5], heads[6], heads[7], heads[8], heads[9]])
        for row in values:
            gpa_details_table.add_row([count, row[4], row[5], row[6], row[7], row[8], row[9]])
            count += 1
        print(gpa_details_table)

    # get lecture
    def _prepare_for_lecture(self):
        # switch to menu and enter gpa page
        self._bar.update(70)
        self._driver.switch_to.frame('menu')
        self._driver.find_element_by_xpath('/html/body/table/tbody/tr[6]/td/table/tbody/tr[2]/td/a/span').click()
        self._driver.switch_to.default_content()
        self._driver.switch_to.frame('body')

        # get page source and parse to soup
        self._bar.update(80)
        self._page_source = self._driver.page_source

    def lecture(self):
        self._bar.update(90)
        self._prepare_for_lecture()

        # switch to first term
        self._bar.update(100)
        self._bar.finish()
        self._get_data_for_lecture()

    def _get_data_for_lecture(self):
        soup = BeautifulSoup(self._page_source, 'lxml')
        week = ['月曜日', '火曜日', '水曜日', '木曜日', '金曜日', '土曜日']
        order = ['1限', '2限', '3限', '4限', '5限', '6限', '7限']

        # get all lecture
        lectures = []
        for lecture in soup.find_all('table', class_='rishu-koma-inner'):
            class_id = lecture.find_all('td')[0].contents[2].strip()
            if class_id == '':
                lectures.append('/')
            else:
                lectures.append(class_id)

        # print lecture list
        table = PrettyTable()
        table.add_column('時間割', order)
        for index in range(5):
            tmp = []
            for count in range(7):
                tmp.append(lectures[index + 6 * count])
            table.add_column(week[index], tmp)
        print(table)
